Internals
============

This section is for internal purposes only and serves to inform developers about
details; because rendered LaTeX is easier to read than source code.


KFAC-related
-------------

.. autofunction:: curvlinops.kfac_utils.loss_hessian_matrix_sqrt
